@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -252,7 +252,7 @@ format_field_simple (const char *fmt, ...)
 void
 format_field_align (const char *fmt, ...)
 {
-  size_t n, width;
+  size_t n, width = 0;
   va_list ap;
 
   va_start (ap, fmt);
