@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -47,7 +47,14 @@ int ident_port;
 char *ident_keyfile;
 int ident_encrypt_only;
 
-int test_mode;
+enum testmode
+  {
+    TEST_MODE_UNDEF = -1,
+    TEST_MODE_OFF   = 0,
+    TEST_MODE_ON    = 1,
+  };
+
+int test_mode = TEST_MODE_UNDEF;
 
 const char *program_version = "imap4d (" PACKAGE_STRING ")";
 
@@ -460,13 +467,16 @@ namespace_section_parser (enum mu_cfg_section_stage stage,
       struct namespace *ns;
       
       if (node->label == NULL || node->label->type != MU_CFG_STRING)
-	return 1;
+	{
+	  mu_error ("%s", _("namespace label is missing or not valid"));
+	  return 1;
+	}
 
       ns = namespace_lookup (node->label->v.string);
       if (!ns)
 	{
 	  mu_error (_("unknown namespace"));
-	  return 0;
+	  return 1;
 	}
 	
       *section_data = ns;
@@ -711,7 +721,7 @@ imap4d_session_setup (char *username)
 }
 
 void
-imap4d_child_signal_setup (RETSIGTYPE (*handler) (int signo))
+imap4d_child_signal_setup (void (*handler) (int signo))
 {
   static int sigtab[] = { SIGPIPE, SIGABRT, SIGINT, SIGQUIT,
 			  SIGTERM, SIGHUP, SIGALRM };
@@ -726,9 +736,6 @@ imap4d_mainloop (int ifd, int ofd, struct imap4d_srv_config *cfg)
   int signo;
   struct imap4d_session session;
 
-  if (!test_mode)
-    test_mode = isatty (ifd);
-
   if ((signo = setjmp (child_jmp)))
     {
       mu_diag_output (MU_DIAG_CRIT, _("got signal `%s'"), strsignal (signo));
@@ -785,7 +792,7 @@ imap4d_mainloop (int ifd, int ofd, struct imap4d_srv_config *cfg)
 
   if (imap4d_preauth_setup (ifd) == 0)
     {
-      if (test_mode)
+      if (test_mode == TEST_MODE_ON)
 	{
 	  mu_diag_output (MU_DIAG_INFO, _("started in test mode"));
 	  text = "IMAP4rev1 Test mode";
@@ -868,7 +875,7 @@ imap4d_check_home_dir (const char *dir, uid_t uid, gid_t gid)
 
 jmp_buf master_jmp;
 
-RETSIGTYPE
+void
 imap4d_master_signal (int signo)
 {
   longjmp (master_jmp, signo);
@@ -932,9 +939,21 @@ main (int argc, char **argv)
     }
 
   namespace_init ();
-  
-  if (test_mode)
+
+  if (test_mode == TEST_MODE_ON)
     mu_m_server_set_mode (server, MODE_INTERACTIVE);
+  else if (test_mode == TEST_MODE_UNDEF)
+    {
+      switch (mu_m_server_mode (server))
+	{
+	case MODE_INTERACTIVE:
+	  test_mode = isatty (MU_STDIN_FD);
+	  break;
+
+	default:
+	  test_mode = TEST_MODE_OFF;
+	}
+    }
   
   if (login_disabled)
     imap4d_capability_add (IMAP_CAPA_LOGINDISABLED);
