@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009, 2011-2012 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ extern mu_stream_t mu_strin;
 extern mu_stream_t mu_strout;
 extern mu_stream_t mu_strerr;
 
-extern const char *mu_program_name;
+extern char *mu_program_name;
   
 #define MU_STRERR_STDERR  0
 #define MU_STRERR_SYSLOG  1
