@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -101,7 +101,7 @@ mutil_parse_field_map (const char *map, mu_assoc_t *passoc_tab, int *perr)
       rc = mu_assoc_install (assoc_tab, tok, pptr);
       if (rc)
 	{
-	  free (p);
+	  free (pptr);
 	  break;
 	}
     }
