@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -106,7 +106,7 @@ _qp_decoder (void *xd,
 	      if (*iptr == '\n')
 		{
 		  iptr++;
-		  consumed++;
+		  consumed += 2;
 		}
 	      else if (consumed + 2 >= isize)
 		/* There must be 2 more characters before I consume this.  */
@@ -114,7 +114,7 @@ _qp_decoder (void *xd,
 	      else if (iptr[0] == '\r' && iptr[1] == '\n')
 		{
 		  iptr += 2;
-		  consumed += 2;
+		  consumed += 3;
 		}
 	      else
 		{
