@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -45,7 +45,7 @@ struct _mu_progmailer
 {
   int fd;
   pid_t pid;
-  RETSIGTYPE (*sighandler)();
+  void (*sighandler)();
   char *command;
 };
 
