@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -132,6 +132,7 @@ mu_stream_seterr (struct _mu_stream *stream, int code, int perm)
     case EINTR:
     case ENOSYS:
     case EINPROGRESS:
+    case MU_ERR_INFO_UNAVAILABLE:
       break;
 
     default:
@@ -774,6 +775,8 @@ mu_stream_read (mu_stream_t stream, void *buf, size_t size, size_t *pread)
       
       if (pread)
 	*pread = nbytes;
+      else if (size)
+	return MU_ERR_READ;
     }
   return 0;
 }
