@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2020 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -55,7 +55,11 @@ mu_stream_copy_wcb (mu_stream_t dst, mu_stream_t src, mu_off_t size,
 	case 0:
 	  break;
 
+	case EAGAIN:
+	case EINTR:
 	case ENOSYS:
+	case EINPROGRESS:
+	case MU_ERR_INFO_UNAVAILABLE:
 	  size = 0;
 	  break;
 
@@ -154,23 +158,27 @@ mu_stream_copy (mu_stream_t dst, mu_stream_t src, mu_off_t size,
 static void
 capture_last_char (char *buf, size_t size, void *data)
 {
-  *(char*)data = buf[size-1];
+  int *n = data;
+  *n = (buf[size-1] == '\n');
 }
 
-/* Same as mu_stream_copy, but also ensures that the copied data end with
-   a '\n' character. */
+/*
+ * Copies data from SRC to DST, appending an empty line (single newline) at
+ * the end.  If data in SRC does not end in a newline character, an additional
+ * newline is appended.
+ */
 int
 mu_stream_copy_nl (mu_stream_t dst, mu_stream_t src, mu_off_t size,
 		   mu_off_t *pcsz)
 {
-  char lc;
+  int lc = 0;
   int status = mu_stream_copy_wcb (dst, src, size, capture_last_char, &lc,
 				   pcsz);
-  if (status == 0 && lc != '\n')
+  if (status == 0)
     {
-      status = mu_stream_write (dst, "\n", 1, NULL);
+      status = mu_stream_write (dst, "\n\n", 2 - lc, NULL);
       if (status == 0 && pcsz)
-	++ *pcsz;
+	*pcsz += 2 - lc;
     }
   return status;
 }
