@@ -40,7 +40,7 @@ EXIT STATUS
 	
 LICENSE
    This file is part of GNU mailutils.
-   Copyright (C) 2020-2022 Free Software Foundation, Inc.
+   Copyright (C) 2020-2023 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -128,7 +128,7 @@ stream_verify_part (mu_stream_t str, int patstart, mu_off_t off, mu_off_t size)
 	{
 	  mu_off_t pos;
 	  MU_ASSERT (mu_stream_seek (str, 0, MU_SEEK_CUR, &pos));
-	  fprintf (stderr, "%lu: chunk differs\n", pos - n);
+	  fprintf (stderr, "%lu: chunk differs\n", (unsigned long) (pos - n));
 	  exit (1);
 	}
       size -= n;
@@ -151,7 +151,7 @@ stream_verify (mu_stream_t str, mu_off_t isize, mu_off_t a, mu_off_t b)
     }
 	
   stream_verify_part (str, 0, 0, a < b ? a : b);
-  stream_verify_part (str, b % sizeof (pattern), a, size);
+  stream_verify_part (str, b % sizeof (pattern), a, size - a);
 }
 
 static void
@@ -174,7 +174,7 @@ file_verify_part (mu_stream_t str, mu_stream_t orig, mu_off_t str_off,
 	{
 	  mu_off_t pos;
 	  MU_ASSERT (mu_stream_seek (str, 0, MU_SEEK_CUR, &pos));
-	  fprintf (stderr, "%lu: chunk differs\n", pos - n);
+	  fprintf (stderr, "%lu: chunk differs\n", (unsigned long) (pos - n));
 	  exit (1);
 	}
       size -= n;
