@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005-2020 Free Software Foundation, Inc.
+   Copyright (C) 2005-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -365,7 +365,7 @@ check_db (mu_sieve_machine_t mach, char *from)
       mu_sieve_abort (mach);
     }
 
-  rc = mu_locker_create (&locker, file, 0);
+  rc = mu_locker_create_ext (&locker, file, NULL);
   if (rc)
     {
       mu_sieve_error (mach, _("%lu: cannot lock %s: %s"),
