@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2022 Free Software Foundation, Inc.
+   Copyright (C) 2011-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -921,6 +921,9 @@ _fill_response (void *item, void *data)
     case env_message_id:
       rc = elt_to_string (elt, &imapenvelope->message_id);
       break;
+
+    default:
+      rc = EINVAL;
     }
   return rc;
 }
