@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -81,7 +81,7 @@ static struct _mu_record _smtp_record = {
   NULL				/* _get_folder method.  */
 };
 
-/* We export : url parsing and the initialisation of
+/* We export : url parsing and the initialization of
    the mailbox, via the register entry/record.  */
 mu_record_t     mu_smtp_record = &_smtp_record;
 
@@ -233,7 +233,7 @@ smtp_open (mu_mailer_t mailer, int flags)
   
   memset (&hints, 0, sizeof (hints));
   hints.flags = MU_AH_DETECT_FAMILY;
-  hints.port = smtp_mailer->tls ? MU_SMTPS_PORT : MU_SMTP_PORT;
+  hints.port = smtp_mailer->tls == MAILER_TLS_ALWAYS ? MU_SMTPS_PORT : MU_SMTP_PORT;
   hints.protocol = IPPROTO_TCP;
   hints.socktype = SOCK_STREAM;
   rc = mu_sockaddr_from_url (&sa, mailer->url, &hints);
@@ -251,20 +251,23 @@ smtp_open (mu_mailer_t mailer, int flags)
   if (smtp_mailer->tls == MAILER_TLS_ALWAYS)
     {
       mu_stream_t tlsstream;
-      
-      rc = mu_tls_client_stream_create (&tlsstream, transport, transport, 0);
+
+      rc = mu_tlsfd_stream_convert (&tlsstream, transport, NULL,
+				    MU_TLS_CLIENT);
       mu_stream_unref (transport);
       if (rc)
 	{
-	  mu_debug (MU_DEBCAT_MAILER, MU_DEBUG_ERROR,
-		    (_("cannot create TLS stream: %s"),
-		     mu_strerror (rc)));
-	  mu_sockaddr_free (sa);
+	  if (rc == MU_ERR_TRANSPORT_SET)
+	    {
+	      mu_stream_destroy (&tlsstream);
+	      mu_tls_enable = 0;
+	    }
+	  mu_debug (MU_DEBCAT_FOLDER, MU_DEBUG_ERROR,
+		    ("cannot create TLS stream: %s", mu_strerror (rc)));
 	  if (mu_tls_enable)
 	    return rc;
 	}
-      else
-	transport = tlsstream;
+      transport = tlsstream;
     }
 #endif
   mu_stream_set_buffer (transport, mu_buffer_line, 0);
