@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2019-2022 Free Software Foundation, Inc.
+   Copyright (C) 2019-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -540,7 +540,8 @@ env_to_stream (struct mu_mboxrd_message const *dmsg,
       mu_stream_seek (dst, 0, MU_SEEK_CUR, &off);
       ref->from_length = off - ref->message_start;
       ref->env_sender_len = strlen (sender);
-      strncpy (ref->date, date, sizeof (ref->date));
+      ref->date[sizeof (ref->date) - 1] = 0;
+      strncpy (ref->date, date, sizeof (ref->date) - 1);
     }
   
   return rc;
