@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 /*
   FIXME:
  decode, this is temporary, until the API on how to present
- mime/attachements etc is less confusing.
+ mime/attachments etc is less confusing.
  */
 
 struct decode_closure
@@ -41,7 +41,8 @@ mail_decode (int argc, char **argv)
   msgset_t *msgset;
   struct decode_closure decode_closure;
 
-  if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &msgset))
+  if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT|MSG_ALLOWPART,
+		    &msgset))
     return 1;
 
   decode_closure.select_hdr = mu_islower (argv[0][0]);
@@ -223,7 +224,7 @@ mime_descend (struct mime_descend_closure *closure,
 	   * message (this code is propagated from mu_stream_to_message,
 	   * which does the actual work).
 	   *
-	   * If the enclosing messgae(part) is of message/digest type, it
+	   * If the enclosing message(part) is of message/digest type, it
 	   * is possible that messages are packed into it without MIME
 	   * headers.  That violates RFC 1341, but such digests are
 	   * reported to exist (re. email conversation with Karl on
