@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -479,7 +479,7 @@ mailvar_get (void *ptr, const char *variable, enum mailvar_type type, int warn)
 	break;
 
       case mailvar_type_boolean:
-	*(int*)ptr = var->value.bool;
+	*(int*)ptr = var->value.boolean;
 	break;
 
       default:
@@ -591,7 +591,7 @@ mailvar_set (const char *variable, void *value, enum mailvar_type type,
 	      break;
 
 	    case mailvar_type_boolean:
-	      newvar.value.bool = *(int*)value;
+	      newvar.value.boolean = *(int*)value;
 	      break;
 
 	    default:
@@ -969,7 +969,7 @@ mailvar_printer (void *item, void *data)
       break;
 
     case mailvar_type_boolean:
-      if (!vp->value.bool)
+      if (!vp->value.boolean)
 	mu_stream_printf (clos->out, "no");
       mu_stream_printf (clos->out, "%s", vp->name);
       break;
