@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -119,7 +119,8 @@ int
 mail_print (int argc, char **argv)
 {
   int lower = mu_islower (argv[0][0]);
-  int rc = util_foreach_msg (argc, argv, MSG_NODELETED|MSG_SILENT,
+  int rc = util_foreach_msg (argc, argv,
+			     MSG_NODELETED|MSG_SILENT,
 			     mail_print_msg, &lower);
   return rc;
 }
