@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ top0 (msgset_t *mspec, mu_message_t msg, void *data)
     }
   free (buf);
   mu_stream_destroy (&stream);
-  set_cursor (mspec->msg_part[0]);
+  set_cursor (msgset_msgno (mspec));
 
   util_mark_read (msg);
 
