@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -51,60 +51,55 @@ util_do_command (const char *fmt, ...)
   if (status)
     return status;
 
-  if (cmd)
+  /*  Ignore comments */
+  if (cmd[0] == '#')
     {
-      /*  Ignore comments */
-      if (cmd[0] == '#')
-	{
-	  free (cmd);
-	  return 0;
-	}
+      free (cmd);
+      return 0;
+    }
 
-      if (cmd[0] == '\0')
-	{
-	  free (cmd);
+  if (cmd[0] == '\0')
+    {
+      free (cmd);
 
-	  /* Hitting return i.e. no command, is equivalent to next
-	     according to the POSIX spec. Note, that this applies
-	     to interactive state only. */
-	  if (interactive)
-	    cmd = mu_strdup ("next");
-	  else
-	    return 0;
-	}
-
-      ws.ws_offs = 1; /* Keep one extra slot in case we need it
-			 for expansion (see below) */
-      if (mu_wordsplit (cmd, &ws, MU_WRDSF_DEFFLAGS|MU_WRDSF_DOOFFS))
-	{
-	  mu_error ("\"%s\": %s", cmd, mu_wordsplit_strerror (&ws));
-	  free (cmd);
-	  return MU_ERR_PARSE;
-	}
+      /* Hitting return i.e. no command, is equivalent to next
+	 according to the POSIX spec. Note, that this applies
+	 to interactive state only. */
+      if (interactive)
+	cmd = mu_strdup ("next");
       else
-	{
-	  char *p;
+	return 0;
+    }
 
-	  argc = ws.ws_wordc;
-	  argv = ws.ws_wordv + 1;
-
-	  /* Special case: a number alone implies "print" */
-	  if (argc == 1
-	      && ((strtoul (argv[0], &p, 10) > 0 && *p == 0)
-		  || (argv[0][1] == 0 && strchr ("^$", argv[0][0]))))
-	    {
-	      /* Use the extra slot for "print" command */
-	      argc++;
-	      argv--;
-	      argv[0] = "print";
-	    }
-
-	  entry = mail_find_command (argv[0]);
-	  free (cmd);
-	}
+  ws.ws_offs = 1; /* Keep one extra slot in case we need it
+		     for expansion (see below) */
+  if (mu_wordsplit (cmd, &ws, MU_WRDSF_DEFFLAGS|MU_WRDSF_DOOFFS))
+    {
+      mu_error ("\"%s\": %s", cmd, mu_wordsplit_strerror (&ws));
+      free (cmd);
+      return MU_ERR_PARSE;
     }
   else
-    entry = mail_find_command (mailvar_name_quit);
+    {
+      char *p;
+
+      argc = ws.ws_wordc;
+      argv = ws.ws_wordv + 1;
+
+      /* Special case: a number alone implies "print" */
+      if (argc == 1
+	  && ((strtoul (argv[0], &p, 10) > 0 && *p == 0)
+	      || (argv[0][1] == 0 && strchr ("^$", argv[0][0]))))
+	{
+	  /* Use the extra slot for "print" command */
+	  argc++;
+	  argv--;
+	  argv[0] = "print";
+	}
+
+      entry = mail_find_command (argv[0]);
+      free (cmd);
+    }
 
   if (!entry)
     {
@@ -1223,12 +1218,12 @@ util_get_charset (void)
     {
       struct mu_lc_all lc_all = { .flags = 0 };
       char *tmp = getenv ("LC_ALL");
-      if (!tmp)
+      if (!tmp || !*tmp)
 	tmp = getenv ("LANG");
 
       if (tmp && mu_parse_lc_all (tmp, &lc_all, MU_LC_CSET) == 0)
 	{
-	  charset = mu_strdup (lc_all.charset);
+	  charset = lc_all.charset ? mu_strdup (lc_all.charset) : NULL;
 	  mu_lc_all_free (&lc_all);
 	}
       else
