@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,11 +20,19 @@
 
 #define PY_MODULE "errno"
 
+static struct PyModuleDef moduledef = {
+  PyModuleDef_HEAD_INIT,
+  PY_MODULE,
+  NULL,
+  -1,
+  NULL
+};
+
 void
 _mu_py_attach_errno (void)
 {
   int i;
-  PyObject *module = _mu_py_attach_module (PY_MODULE, NULL);
+  PyObject *module = _mu_py_attach_module (&moduledef);
 
   for (i = MU_ERR_BASE; i < MU_ERR_LAST; i++)
     {
